@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
-# $Id: views.py 241856 2011-07-04 10:00:04Z mborch $
+# $Id: views.py 241878 2011-07-05 08:23:59Z mborch $
 
 from zope.component import getMultiAdapter
 from zope.component import getSiteManager
 from zope.component import ComponentLookupError
 from zope.interface import providedBy
 from zope.interface import Interface
-from zope.location.interfaces import LocationError
 from zope.i18n import translate
 from plone.memoize.view import memoize_contextless
 from Products.CMFCore.utils import getToolByName
@@ -19,6 +18,12 @@ from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.statusmessages.interfaces import IStatusMessage
 
 
+try:
+    from zope.location.interfaces import LocationError
+except ImportError:
+    LocationError = AttributeError
+
+
 def test(condition, value_true, value_false):
     if condition:
         return value_true
@@ -33,8 +38,6 @@ class BaseView(BrowserView):
 
     catch_exceptions = (
         NameError,
-        ValueError,
-        TypeError,
         LocationError,
         )
 
